/*
    ChibiOS/RT - Copyright (C) 2006,2007,2008,2009,2010,
                 2011,2012 Giovanni Di Sirio.

    This file is part of ChibiOS/RT.

    ChibiOS/RT is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    ChibiOS/RT is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "ch.h"
#include "hal.h"

/**
 * @brief   PAL setup.
 * @details Digital I/O ports static configuration as defined in @p board.h.
 *          This variable is used by the HAL when initializing the PAL driver.
 */
#if HAL_USE_PAL || defined(__DOXYGEN__)
const PALConfig pal_default_config = {
 {VAL_GPIO0DATA, VAL_GPIO0DIR},
 {VAL_GPIO1DATA, VAL_GPIO1DIR},
 {VAL_GPIO2DATA, VAL_GPIO2DIR},
 {VAL_GPIO3DATA, VAL_GPIO3DIR},
};
#endif

/*
 * Early initialization code.
 * This initialization must be performed just after stack setup and before
 * any other initialization.
 */
void __early_init(void) {
    lpc111x_clock_init();
}

/*
 * Board-specific initialization code.
 */
void boardInit(void) {
    LPC_SYSCON->SYSAHBCLKCTRL |= (1 << 16); // Enable IOCON

#if 0
    LPC_IOCON->PIO0_8        = 0x4C0; // Pin 1  -- PIO0_8       | CPU_COL2
    LPC_IOCON->PIO0_9        = 0x4C0; // Pin 2  -- PIO0_9       | CPU_COL3
//  LPC_IOCON->SWCLK_PIO0_10 = 0x4C1; // Pin 3  -- PIO0_10      | LED_ROW5
    LPC_IOCON->R_PIO0_11     = 0x4C1; // Pin 4  -- PIO0_11/AD0  | FADER1
#endif

    LPC_IOCON->PIO0_5        = 0x100; // Pin 5  -- PIO0_5 (OpenCollector only) | I2C_SDA

#if 0
    LPC_IOCON->PIO0_6        = 0x4C0; // Pin 6  -- PIO0_6       | ROW2
    // LPC1114FN28 Pin 7  --  VddA
    // LPC1114FN28 Pin 8  --  VssA
    LPC_IOCON->R_PIO1_0      = 0x4C1; // Pin 9  -- PIO1_0/AD1   | FADER2
    LPC_IOCON->R_PIO1_1      = 0x4C1; // Pin 10 -- PIO1_1/AD2   | FADER3
    LPC_IOCON->R_PIO1_2      = 0x4C1; // Pin 11 -- PIO1_2/AD3   | FADER4
//  LPC_IOCON->SWDIO_PIO1_3  = 0x4C1; // Pin 12 -- PIO1_3/AD4   | LED_ROW4
    LPC_IOCON->PIO1_4        = 0x4C0; // Pin 13 -- PIO1_4/AD5   | FADER5
    LPC_IOCON->PIO1_5        = 0x4C0; // Pin 14 -- PIO1_5       | ROW3
#endif

    LPC_IOCON->PIO1_6        = 0xC0;  // Pin 15 -- PIO1_6 / RxD | UART_RXD
    LPC_IOCON->PIO1_7        = 0x4C0; // Pin 16 -- PIO1_7 / TxD | UART_TXD

#if 0
    LPC_IOCON->PIO1_8        = 0x4C0; // Pin 17 -- PIO1_8       | LED_ROW3
    LPC_IOCON->PIO1_9        = 0x4C0; // Pin 18 -- PIO1_9       | LED_ROW2
    // LPC1114FN28 Pin 19 -- XTALOUT
    // LPC1114FN28 Pin 20 -- XTALIN
    // LPC1114FN28 Pin 21 -- Vdd
    // LPC1114FN28 Pin 22 -- Vss
//  LPC_IOCON->PIO0_0        = 0x4C0;    // Pin 23 | PIO0_0 / RESET | CPU_COL5
    LPC_IOCON->PIO0_1        = 0x4C0;    // Pin 24 | PIO0_1 / ISP   | ROW1
    LPC_IOCON->PIO0_2        = 0x4C0;    // Pin 25 | PIO0_2         | CPU_COL4
    LPC_IOCON->PIO0_3        = 0x4C0;    // Pin 26 | PIO0_3         | CPU_COL1
#endif
    LPC_IOCON->PIO0_4        = 0x100;    // Pin 27 | PIO0_4 (OpenCollector only) | I2C_SCL
#if 0
    LPC_IOCON->PIO0_7        = 0x4C0;    // Pin 28 | PIO0_7         | LED_ROW1
  // LPC_IOCON->PIO1_9 = 0xC0;             /* Disables pull-up on LED3R output.*/
  // LPC_IOCON->PIO1_10 = 0xC0;            /* Disables pull-up on LED3G output.*/
#endif
}
