#ifndef DEFINED_UMP
#define DEFINED_UMP

#include "ump_frame.h"
#include <stdint.h>

struct UmpInterface;
struct UmpCallbacks
{
    void (*start_uart) (struct UmpInterface *_ump);
    void (*stop_uart) (struct UmpInterface *_ump);
    void (*uart_send_octet) (struct UmpInterface *_ump, const uint8_t _octet);

    void (*init_timer) (struct UmpInterface *_ump);
    void (*restart_timeout) (struct UmpInterface * _ump, const uint16_t _timeout_ms);
    void (*stop_timeout) (struct UmpInterface * _ump);
    void (*frame_received)(struct UmpInterface *, struct UmpFrame *);
};

struct UmpInterface
{
    uint8_t my_id;
    uint8_t state;

    const struct UmpCallbacks * callbacks;
    void (*frameReceivedCallback)(struct UmpFrame *);

    struct
    {
	uint16_t size;
	uint16_t index;
	uint8_t  expected_txdata;
	uint8_t  data[128];
	const struct UmpFrame * txFrame;
    } tx;
    
    struct
    {
	uint8_t  rxstate;
	uint8_t  crc8;
	uint16_t index;
	struct UmpFrame frame;
    } rx;
};

void ump_init(struct UmpInterface *_ump, const struct UmpCallbacks * _callbacks, void (*_frameReceivedCallback)(struct UmpFrame *));
void ump_start(struct UmpInterface *_ump);
void ump_send_frame(struct UmpInterface *_ump, const struct UmpFrame * _txFrame);
void ump_stop(struct UmpInterface *_ump);
void ump_set_my_id(struct UmpInterface *_ump, const uint8_t _my_id);

/*-- interrupt handlers to call --*/
extern void ump_handle_received_data(struct UmpInterface *_ump, const uint8_t _rxdata);
extern void ump_handle_rxerror(struct UmpInterface *_ump);
extern void ump_handle_transmitbuffer_empty(struct UmpInterface *_ump);
extern void ump_handle_transmitter_empty(struct UmpInterface *_ump);
extern void ump_handle_timer_interrupt(struct UmpInterface *_ump);

#endif // DEFINED_UMP
